@@ -1,5 +1,5 @@
 pref("extensions.ImapAclExt.advMode", false);
-pref("extensions.ImapAclExt.compatMode", false);
+//N//pref("extensions.ImapAclExt.compatMode", false);
 pref("extensions.ImapAclExt.version", "0.0.0");
 // https://developer.mozilla.org/en/Localizing_extension_descriptions
 pref("extensions.imap-acl@sirphreak.com.description", "chrome://imapaclext/locale/overlay.properties");
